(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     36352,        864]*)
(*NotebookOutlinePosition[     37057,        888]*)
(*  CellTagsIndexPosition[     37013,        884]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Fitting of motor parameters to finite element inductance results.\
\>", "Subsubtitle"],

Cell["\<\
This information was obtained via finite element analysis.  The first column \
is frequency in Hz, the second is the real part of the inductance of one \
phase, and the third column is the imaginary part of the inductance of one \
phase.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"a", "=", 
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"0.25`", "0.3113896850223534`", \(-0.07856218453620856`\)},
              {"0.5`", "0.2644535219245725`", \(-0.1302070241302897`\)},
              {"0.75`", "0.2126343173595966`", \(-0.15379008725956922`\)},
              {"1.`", "0.168320257396424`", \(-0.15836166677785932`\)},
              {"1.25`", "0.13420429270682951`", \(-0.15323033612409562`\)},
              {"1.5`", "0.10889119962460642`", \(-0.1441388199690263`\)},
              {"1.75`", "0.09020968041951417`", \(-0.1339803795461847`\)},
              {"2.`", "0.07630198291077502`", \(-0.1240517339450469`\)},
              {"2.25`", "0.06579818291161289`", \(-0.1148644116425449`\)},
              {"2.5`", "0.057736014348538645`", \(-0.1065680060490867`\)},
              {"2.75`", "0.05144745255439016`", \(-0.09915441223769653`\)},
              {"3.`", "0.0464668655223232`", \(-0.09255306693744175`\)}
              }], "\[NoBreak]", ")"}],
        Function[ BoxForm`e$, 
          MatrixForm[ BoxForm`e$]]], " "}]], "Input"],

Cell[BoxData[
    \({{0.25`, 0.3113896850223534`, \(-0.07856218453620856`\)}, {0.5`, 
        0.2644535219245725`, \(-0.1302070241302897`\)}, {0.75`, 
        0.2126343173595966`, \(-0.15379008725956922`\)}, {1.`, 
        0.168320257396424`, \(-0.15836166677785932`\)}, {1.25`, 
        0.13420429270682951`, \(-0.15323033612409562`\)}, {1.5`, 
        0.10889119962460642`, \(-0.1441388199690263`\)}, {1.75`, 
        0.09020968041951417`, \(-0.1339803795461847`\)}, {2.`, 
        0.07630198291077502`, \(-0.1240517339450469`\)}, {2.25`, 
        0.06579818291161289`, \(-0.1148644116425449`\)}, {2.5`, 
        0.057736014348538645`, \(-0.1065680060490867`\)}, {2.75`, 
        0.05144745255439016`, \(-0.09915441223769653`\)}, {3.`, 
        0.0464668655223232`, \(-0.09255306693744175`\)}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(a = Transpose[a];\)\)], "Input"],

Cell["\<\
Scale frequency so that it is in units of rad/sec.  For convenience, denote \
the columns of data w, Lr and Li\
\>", "Text"],

Cell[BoxData[{
    \(\(w = 2\ Pi\ a[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(\(Lr = a[\([2]\)];\)\), "\[IndentingNewLine]", 
    \(\(Li = a[\([3]\)];\)\)}], "Input"],

Cell["\<\
Build matrices necessary for the first problem to get tau and M:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A = Transpose[{w, \ w*w*Li}]\)], "Input"],

Cell[BoxData[
    \({{1.5707963267948966`, \(-0.19384442056443957`\)}, {3.141592653589793`, \
\(-1.2850918184090556`\)}, {4.71238898038469`, \(-3.415156474637162`\)}, \
{6.283185307179586`, \(-6.251868013578426`\)}, {7.853981633974483`, \
\(-9.452017498692348`\)}, {9.42477796076938`, \(-12.803338187407158`\)}, \
{10.995574287564276`, \(-16.198583459450926`\)}, {12.566370614359172`, \
\(-19.589464628908818`\)}, {14.137166941154069`, \(-22.956742629184966`\)}, \
{15.707963267948966`, \(-26.294601537934586`\)}, {17.27875959474386`, \
\(-29.60309840811009`\)}, {18.84955592153876`, \(-32.88463764408335`\)}}\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b = \(-Li\)\)], "Input"],

Cell[BoxData[
    \({0.07856218453620856`, 0.1302070241302897`, 0.15379008725956922`, 
      0.15836166677785932`, 0.15323033612409562`, 0.1441388199690263`, 
      0.1339803795461847`, 0.1240517339450469`, 0.1148644116425449`, 
      0.1065680060490867`, 0.09915441223769653`, 
      0.09255306693744175`}\)], "Output"]
}, Open  ]],

Cell["Solve least-squares problem", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ans = Inverse[Transpose[A] . A] . Transpose[A] . b\)], "Input"],

Cell[BoxData[
    \({0.05229063612826287`, 0.02718468414214296`}\)], "Output"]
}, Open  ]],

Cell["and infer values of tau and M from the results", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tau = Sqrt[ans[\([2]\)]]\)], "Input"],

Cell[BoxData[
    \(0.16487778547197607`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(M = ans[\([1]\)]/tau\)], "Input"],

Cell[BoxData[
    \(0.31714785578042953`\)], "Output"]
}, Open  ]],

Cell["Plot the fit versus the \"data\"", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FitLi = \(-tau\)\ ws\ M/\((1\  + \ \((tau\ ws)\)^2)\)\)], "Input"],

Cell[BoxData[
    \(\(-\(\(0.05229063612826287`\ ws\)\/\(1 + 
            0.02718468414214296`\ ws\^2\)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(dataplot1 = 
        ListPlot[Transpose[{w, Li}], 
          DisplayFunction \[Rule] Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(fitplot1 = 
        Plot[FitLi, {ws, 0, 20}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[dataplot1, fitplot1, 
      DisplayFunction \[Rule] $DisplayFunction]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.603319 3.71186 [
[.2619 .59082 -3 -9 ]
[.2619 .59082 3 0 ]
[.5 .59082 -6 -9 ]
[.5 .59082 6 0 ]
[.7381 .59082 -6 -9 ]
[.7381 .59082 6 0 ]
[.97619 .59082 -6 -9 ]
[.97619 .59082 6 0 ]
[.01131 .04654 -30 -4.5 ]
[.01131 .04654 0 4.5 ]
[.01131 .13934 -36 -4.5 ]
[.01131 .13934 0 4.5 ]
[.01131 .23213 -24 -4.5 ]
[.01131 .23213 0 4.5 ]
[.01131 .32493 -36 -4.5 ]
[.01131 .32493 0 4.5 ]
[.01131 .41773 -30 -4.5 ]
[.01131 .41773 0 4.5 ]
[.01131 .51052 -36 -4.5 ]
[.01131 .51052 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(5)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(10)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(15)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(20)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .04654 m
.03006 .04654 L
s
[(-0.15)] .01131 .04654 1 0 Mshowa
.02381 .13934 m
.03006 .13934 L
s
[(-0.125)] .01131 .13934 1 0 Mshowa
.02381 .23213 m
.03006 .23213 L
s
[(-0.1)] .01131 .23213 1 0 Mshowa
.02381 .32493 m
.03006 .32493 L
s
[(-0.075)] .01131 .32493 1 0 Mshowa
.02381 .41773 m
.03006 .41773 L
s
[(-0.05)] .01131 .41773 1 0 Mshowa
.02381 .51052 m
.03006 .51052 L
s
[(-0.025)] .01131 .51052 1 0 Mshowa
.125 Mabswid
.02381 .0651 m
.02756 .0651 L
s
.02381 .08366 m
.02756 .08366 L
s
.02381 .10222 m
.02756 .10222 L
s
.02381 .12078 m
.02756 .12078 L
s
.02381 .1579 m
.02756 .1579 L
s
.02381 .17646 m
.02756 .17646 L
s
.02381 .19501 m
.02756 .19501 L
s
.02381 .21357 m
.02756 .21357 L
s
.02381 .25069 m
.02756 .25069 L
s
.02381 .26925 m
.02756 .26925 L
s
.02381 .28781 m
.02756 .28781 L
s
.02381 .30637 m
.02756 .30637 L
s
.02381 .34349 m
.02756 .34349 L
s
.02381 .36205 m
.02756 .36205 L
s
.02381 .38061 m
.02756 .38061 L
s
.02381 .39917 m
.02756 .39917 L
s
.02381 .43629 m
.02756 .43629 L
s
.02381 .45484 m
.02756 .45484 L
s
.02381 .4734 m
.02756 .4734 L
s
.02381 .49196 m
.02756 .49196 L
s
.02381 .52908 m
.02756 .52908 L
s
.02381 .54764 m
.02756 .54764 L
s
.02381 .5662 m
.02756 .5662 L
s
.02381 .58476 m
.02756 .58476 L
s
.02381 .02798 m
.02756 .02798 L
s
.02381 .00942 m
.02756 .00942 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.09861 .31171 Mdot
.17341 .12001 Mdot
.24821 .03247 Mdot
.32301 .0155 Mdot
.39781 .03455 Mdot
.47261 .0683 Mdot
.54741 .106 Mdot
.62221 .14286 Mdot
.69701 .17696 Mdot
.77181 .20775 Mdot
.84661 .23527 Mdot
.92141 .25977 Mdot
.5 Mabswid
.02381 .60332 m
.06244 .44861 L
.10458 .29798 L
.14415 .18537 L
.18221 .10698 L
.20178 .07755 L
.22272 .0534 L
.23293 .04411 L
.24402 .03571 L
.25361 .02977 L
.26416 .02451 L
.2744 .0206 L
.284 .01791 L
.28929 .0168 L
.29413 .016 L
.2968 .01565 L
.29972 .01533 L
.30247 .01509 L
.30503 .01492 L
.30631 .01486 L
.30767 .0148 L
.30883 .01477 L
.31011 .01474 L
.31082 .01473 L
.31148 .01472 L
.31223 .01472 L
.31294 .01472 L
.31421 .01472 L
.31493 .01473 L
.3156 .01475 L
.31678 .01477 L
.31789 .01481 L
.32042 .01492 L
.32289 .01507 L
.32555 .01528 L
.33028 .01575 L
.33526 .01639 L
.34416 .01786 L
.3639 .02249 L
.38227 .02819 L
.42131 .04352 L
.46281 .06279 L
.50279 .08276 L
.54126 .10233 L
.58218 .12294 L
.62158 .14219 L
.65947 .15997 L
.69981 .178 L
.73863 .19443 L
.77991 .21091 L
Mistroke
.81967 .22583 L
.85791 .23934 L
.89861 .25286 L
.93779 .2651 L
.97619 .27639 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{451.938, 279.313},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007300015b000`400?l00000o`00003oo`3oooo4
0?ooo`00o`3oooo40?ooo`00o`3oooo40?ooo`00o`3oooo40?ooo`00o`3oooo40?ooo`00o`3oooo4
0?ooo`00o`3oooo40?ooo`00o`3oooo40?ooo`00o`3oooo40?ooo`00o`3oooo40?ooo`00:@3oool0
0`000000oooo0?ooo`3o0?oooiP0oooo000Y0?ooo`030000003oool0oooo0?l0ooooV03oool002T0
oooo00<000000?ooo`3oool0o`3ooonH0?ooo`00:@3oool00`000000oooo0?ooo`3o0?oooiP0oooo
000Y0?ooo`800000o`3ooonI0?ooo`00:@3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0
oooo0?l0oooo6`3oool002T0oooo00<000000?ooo`3oool0KP3oool@00000?l0oooo6P3oool002T0
oooo00<000000?ooo`3oool0J@3oool5000000`0oooo00@000000?ooo`3oool0oooo1`00003o0?oo
oa<0oooo000Y0?ooo`030000003oool0oooo06H0oooo0`00000L0?ooo`@00000o`3oool?0?ooo`00
:@3oool00`000000oooo0?ooo`1T0?ooo`8000008`3oool400000?l0oooo2`3oool002T0oooo00<0
00000?ooo`3oool0H@3oool3000002T0oooo1000003o0?ooo`L0oooo000Y0?ooo`800000H03oool2
00000300oooo1000003o0?ooo`<0oooo000Y0?ooo`030000003oool0oooo05/0oooo00@000000?oo
o`0000000000=P3oool200000?l0oooo0@3oool002T0oooo00<000000?ooo`3oool0FP3oool30000
03X0oooo1000003l0?ooo`00:@3oool00`000000oooo0?ooo`1J0?ooo`800000?@3oool300000?/0
oooo000Y0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0?P3oool010000000oooo
00000000003i0?ooo`00:@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo04<0oooo
0`00003f0?ooo`003P3oool2000000@0oooo0P0000030?ooo`D000000P3oool2000000L0oooo00<0
00000?ooo`3oool0EP3oool2000004T0oooo0P00003d0?ooo`003@3oool010000000oooo0?ooo`00
000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool0B`3oool300000?40oooo000=0?ooo`040000003o
ool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`<00000
E03oool00`000000oooo0?ooo`1?0?ooo`800000k`3oool000L0oooo100000020?ooo`040000003o
ool0oooo000000X0oooo00<000000?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0
DP3oool2000005@0oooo0P00003]0?ooo`003@3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo05H0oooo0P00003[0?ooo`003P3oool2000000X0oooo0P0000040?ooo`<000001P3o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo05T0oooo0P00003Y0?ooo`00:@3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo05`0oooo0P00003W0?ooo`00:@3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo05l0oooo0P00003U0?ooo`00:@3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo0680oooo0P00003S0?ooo`00:@3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo06D0oooo0`00003P0?ooo`00:@3oool2000004`0oooo00<0
00000?ooo`3oool0J@3oool300000=d0oooo000Y0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0JP3oool300000=`0oooo000Y0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0K03oool010000000oooo00000000003J0?ooo`00:@3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo0740oooo0P00003H0?ooo`00:@3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo07@0oooo0P00003F0?ooo`00:@3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo07L0oooo0P00003D0?ooo`00:@3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo07X0oooo0P00003B0?ooo`00:@3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo07`0oooo0P00003@0?ooo`00:@3oool2000004H0oooo00<000000?ooo`3oool0O`3oool20000
0<h0oooo000Y0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0P@3oool200000<`0
oooo000Y0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0Q03oool200000<X0oooo
000Y0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`370?ooo`00:@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo08P0oooo0P000037
0?ooo`00:@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo08/0oooo0P0000350?oo
o`00:@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo08h0oooo0P0000330?ooo`00
:@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0900oooo0P0000310?ooo`00:@3o
ool200000440oooo00<000000?ooo`3oool0T`3oool300000;h0oooo000Y0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0U03oool300000;d0oooo000Y0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0UP3oool010000000oooo00000000002k0?ooo`00:@3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo09/0oooo0P00002i0?ooo`00:@3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo09d0oooo0P00002g0?ooo`00:@3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo0:00oooo0P00002e0?ooo`00:@3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool000000:@0oooo0P00002c0?ooo`00:@3oool2000003/0oooo0`00002W
0?ooo`800000/@3oool002T0oooo00<000000?ooo`3oool0>`3oool200000:T0oooo0`00002^0?oo
o`00:@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0:/0oooo0P00002/0?ooo`00
:@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0:d0oooo0P00002Z0?ooo`00:@3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0;00oooo0P00002X0?ooo`00:@3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0;80oooo0P00002V0?ooo`00203oool20000
00@0oooo0P0000030?ooo`D0000000<0oooo0000000000000P0000030?ooo`8000001`3oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo0;D0oooo0P00002T0?ooo`001`3oool010000000
oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0]`3oool200000:80oooo0007
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo0`00000h0?ooo`030000003oool0oooo0;X0oooo0P00
002P0?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo0;`0oooo0P00002N0?ooo`001`3oool010000000oooo0?ooo`00
000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000P0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2m0?ooo`@00000W03oool000P0oooo
0P00000:0?ooo`800000103oool2000000@0oooo0`0000060?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`02000009X0oooo000Y0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0a03oool2000009P0oooo000Y0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0aP3oool2000009H0oooo000Y0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0b@3oool2000009@0oooo000Y0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0b`3oool200000980oooo000Y0?ooo`800000=@3oool00`000000oooo
0?ooo`3>0?ooo`800000T03oool002T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`3@0?ooo`<00000S@3oool002T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3D
0?ooo`800000R`3oool002T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3F0?oo
o`800000R@3oool002T0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3I0?ooo`80
0000Q`3oool002T0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3K0?ooo`<00000
Q03oool002T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3O0?ooo`800000PP3o
ool002T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3Q0?ooo`<00000O`3oool0
02T0oooo0P00000a0?ooo`030000003oool0oooo0><0oooo1000001m0?ooo`00:@3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool00P00001k0?ooo`00
:@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0>X0oooo0`00001h0?ooo`00:@3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0>d0oooo0P00001f0?ooo`00:@3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0>l0oooo0P00001d0?ooo`00:@3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0?80oooo0`00001a0?ooo`00:@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo0?D0oooo0P00001_0?ooo`00:@3oool2000002l0oooo
00<000000?ooo`3oool0m`3oool3000006`0oooo000Y0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0n`3oool2000006X0oooo000Y0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0o@3oool3000006L0oooo000Y0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0o`3oool10?ooo`800000I@3oool002T0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`3o0?ooo`@0oooo0P00001S0?ooo`00:@3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo0?l0oooo1P3oool4000005l0oooo000Y0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0o`3oool80?ooo`<00000GP3oool002T0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`0000000P00001K0?ooo`00:@3oool20000
02`0oooo00<000000?ooo`3oool0o`3oool?0?ooo`<00000F03oool002T0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`3o0?oooa80oooo0`00001E0?ooo`00:@3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0?l0oooo5P3oool2000005<0oooo000Y0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0o`3ooolH0?ooo`<00000D03oool002T0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?oooa/0oooo0`00001=0?ooo`00:@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0oooo7`3oool3000004X0oooo000D0?ooo`80
0000103oool2000000<0oooo1@0000050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0o`3ooolR0?ooo`800000B03oool001<0oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`<0
0000A@3oool001<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`050?ooo`<0
0000:03oool00`000000oooo0?ooo`3o0?ooobP0oooo0`0000120?ooo`003@3oool400000080oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0o`3oool[0?ooo`800000@03oool001<0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool0o`3oool[0?ooo`D00000?@3oool001@0oooo0P00000:0?ooo`8000001`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0?l0oooo;@3oool010000000oooo0?ooo`3oool3000003X0
oooo000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0o`3ooold0?ooo`<00000
=`3oool002T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?ooocL0oooo0`00
000d0?ooo`00:@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0oooo>`3oool2
00000380oooo000Y0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0o`3ooolm0?oo
o`<00000;`3oool002T0oooo0P00000W0?ooo`030000003oool0oooo0?l0oooo@03oool3000002`0
oooo000Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0o`3ooom40?ooo`<00000
:@3oool002T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?ooodL0oooo0`00
000V0?ooo`00:@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0ooooBP3oool3
000000030?ooo`000000oooo0200oooo000Y0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0o`3ooom>0?ooo`@000007`3oool002T0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`3o0?ooodl0oooo00<000000?ooo`3oool00`00000L0?ooo`00:@3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0?l0ooooE@3oool3000001T0oooo000Y0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`<000005P3oool002T0oooo0P00000T
0?ooo`030000003oool0oooo0?l0ooooG03oool3000001<0oooo000Y0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0o`3ooomO0?ooo`@000003`3oool002T0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`3o0?ooof@0oooo0`00000<0?ooo`00:@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0?l0ooooI`3oool2000000X0oooo000Y0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0o`3ooomc0?ooo`00:@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0?l0ooooM03oool002T0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`3o0?ooog@0oooo000Y0?ooo`8000008P3oool00`000000oooo0?ooo`3o0?ooog@0
oooo000Y0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0o`3ooome0?ooo`00:@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooM@3oool002T0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`3o0?ooogD0oooo000Y0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0o`3ooomf0?ooo`00:@3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0?l0ooooMP3oool002T0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`3o0?ooogH0oooo000Y0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3o
oomg0?ooo`00:@3oool2000001l0oooo00<000000?ooo`3oool0o`3ooomg0?ooo`00:@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0ooooM`3oool002T0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0000003o0?ooogT0oooo000Y0?ooo`030000003oool0oooo01/0oooo
0`00003o0?ooogX0oooo000Y0?ooo`030000003oool0oooo01`0oooo0P00003o0?ooogX0oooo000Y
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0o`3ooomh0?ooo`00203oool20000
00@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0ooooN@3oool000L0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3o
oomi0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`<00000703oool00`000000oooo
0?ooo`3o0?ooogT0oooo00000`3oool000000000000200000080oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0?ooo`8000001`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0ooooN@3oool000L0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0ooooNP3o
ool000P0oooo0P00000:0?ooo`8000000`3oool4000000<0oooo0`0000060?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`00:@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0?l0ooooNP3oool002T0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`3o0?ooog/0oooo000Y0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
o`3ooomk0?ooo`00:@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0?l0ooooN`3o
ool002T0oooo0P00000K0?ooo`030000003oool0oooo0?l0ooooN`3oool002T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`3o0?ooog`0oooo000Y0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0o`3oooml0?ooo`00:@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo0?l0ooooO03oool002T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`3o0?ooogd0oooo000Y0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooomm
0?ooo`00:@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0ooooO@3oool002T0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o0?ooogd0oooo000Y0?ooo`800000
603oool00`000000oooo0?ooo`3o0?ooogh0oooo000Y0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0o`3ooomn0?ooo`00:@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0?l0ooooOP3oool002T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?oo
ogl0oooo000Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00
:@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0ooooO`3oool002T0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooogl0oooo000Y0?ooo`8000005P3oool0
0`000000oooo0?ooo`3o0?oooh00oooo000Y0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0o`3ooon00?ooo`00:@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0
ooooP03oool002T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?oooh40oooo
000Y0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooon10?ooo`00:@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0ooooP@3oool002T0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`3o0?oooh40oooo000Y0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0o`3ooon20?ooo`00:@3oool2000001@0oooo00<000000?ooo`3oool0
o`3ooon20?ooo`00:@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0ooooPP3o
ool002T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?oooh<0oooo000Y0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0o`3ooon30?ooo`00:@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooP`3oool002T0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`3o0?oooh<0oooo000>0?ooo`800000103oool2000000@0oooo0P00
00040?ooo`8000001`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooQ03o
ool000d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?oooh@0
oooo000=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`040?ooo`<000004@3oool00`000000oooo0?ooo`3o0?oooh@0oooo00070?ooo`@0
00000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo0P000007
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooon50?ooo`003@3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooQ@3oool000h0oooo0P00000:
0?ooo`800000103oool3000000H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o
0?ooohD0oooo000Y0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooon50?oo
o`00:@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooQP3oool002T0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooohH0oooo000Y0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0o`3ooon60?ooo`00:@3oool2000000l0oooo00<00000
0?ooo`3oool0o`3ooon70?ooo`00:@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0?l0ooooQ`3oool002T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooohL0
oooo000Y0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooon70?ooo`00:@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooR03oool002T0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooohP0oooo000Y0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0o`3ooon80?ooo`00:@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0?l0ooooR03oool002T0oooo0P00000=0?ooo`030000003oool0oooo0?l0oooo
R@3oool002T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooohT0oooo000Y
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooon90?ooo`00:@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooR@3oool002T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`3o0?ooohX0oooo000Y0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0o`3ooon:0?ooo`00:@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0?l0ooooRP3oool002T0oooo0P00000<0?ooo`030000003oool0oooo0?l0ooooRP3oool0
02T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oooh/0oooo000Y0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`00:@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooR`3oool002T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`3o0?oooh/0oooo000Y0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0o`3ooon<0?ooo`00:@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0?l0ooooS03oool002T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooh`0
oooo000Y0?ooo`8000002P3oool00`000000oooo0?ooo`3o0?oooh`0oooo000Y0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0o`3ooon=0?ooo`00:@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0?l0ooooS@3oool002T0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`3o0?ooohd0oooo000Y0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0o`3ooon=0?ooo`00:@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo
SP3oool000P0oooo0P0000040?ooo`800000103oool2000000<0oooo100000030?ooo`8000001`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooSP3oool000L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0
ooooSP3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool3000000L0oooo00<000000?oo
o`3oool0o`3ooon>0?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`8000001`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooS`3oool000L0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo
S`3oool000P0oooo0P00000:0?ooo`800000103oool2000000@0oooo0`0000060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0o`3ooon?0?ooo`00:@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0?l0ooooS`3oool002T0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3o0?oooi00oooo000Y0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0o`3ooon@0?ooo`00:@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo
T03oool002T0oooo0P0000060?ooo`030000003oool0oooo0?l0ooooT03oool002T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooi40oooo000Y0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0o`3ooonA0?ooo`00:@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0?l0ooooT@3oool002T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`3o0?oooi40oooo000Y0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3o
oonB0?ooo`00:@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooTP3oool0
02T0oooo0P0000040?ooo`030000003oool0oooo0?l0ooooTP3oool002T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3o0?oooi80oooo000Y0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0o`3ooonC0?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0?l0ooooT`3oool002T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o
0?oooi<0oooo000Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonC0?oo
o`00:@3oool01@000000oooo0?ooo`3oool000000?l0ooooUP3oool002T0oooo00D000000?ooo`3o
ool0oooo0000003o0?oooiH0oooo000Y0?ooo`8000000P3oool00`000000oooo0?ooo`3o0?oooi@0
oooo000Y0?ooo`050000003oool0oooo0?ooo`000000o`3ooonF0?ooo`00:@3oool010000000oooo
0?ooo`00003o0?oooiL0oooo000Y0?ooo`040000003oool0oooo000005l0oooo0P00001N0?ooo`D0
00000P3oool2000005/0oooo1@0000020?ooo`800000FP3oool4000000<0oooo0P0000070?ooo`00
:@3oool010000000oooo0?ooo`00001N0?ooo`040000003oool0oooo000005l0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo05X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000060?ooo`00:@3oool010000000oooo0?ooo`00001Q0?ooo`030000003oool0oooo05d0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000001P3oool002T0oooo00<000000?ooo`000000H03oool200000600oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool00P3oool20000
05`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo000Y0?oo
o`030000003oool000000600oooo00<000000?ooo`3oool0G`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo05T0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`00:@3o
ool300000600oooo0`00001N0?ooo`800000103oool2000005`0oooo0P0000040?ooo`<00000FP3o
ool2000000@0oooo0P0000070?ooo`00:@3oool00`000000oooo0000003o0?oooiP0oooo000Y0?oo
o`800000o`3ooonI0?ooo`00:@3oool200000?l0ooooV@3oool002T0oooo0P00003o0?oooiT0oooo
000Y0?ooo`800000o`3ooonI0?ooo`00:@3oool00`000000oooo0?ooo`3o0?oooiP0oooo000Y0?oo
o`030000003oool0oooo0?l0ooooV03oool001l0ooooo`00002U00000000:@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203oool002T0oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`080?ooo`00:@3oool00`000000oooo0?ooo`3o
0?oooiP0oooo000Y0?ooo`030000003oool0oooo0?l0ooooV03oool002T0oooo00<000000?ooo`3o
ool0o`3ooonH0?ooo`00:@3oool00`000000oooo0?ooo`3o0?oooiP0oooo003o0?oool@0oooo003o
0?oool@0oooo003o0?oool@0oooo003o0?oool@0oooo003o0?oool@0oooo003o0?oool@0oooo003o
0?oool@0oooo003o0?oool@0oooo003o0?oool@0oooo0000\
\>"],
  ImageRangeCache->{{{0, 450.938}, {278.313, 0}} -> {-2.06397, -0.168617, \
0.0500382, 0.000641934}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Now, get the leakage from the real part of the inductance.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Lr - M/\((1 + \((tau\ w)\)^2)\)\)], "Input"],

Cell[BoxData[
    \({0.014177491540164788`, 0.014396488021695242`, 0.014871721428690893`, 
      0.0153458294092155`, 0.015727966063675186`, 0.0160144846599347`, 
      0.016225538339895748`, 0.01638173969148722`, 0.0164989316139844`, 
      0.0165883376829672`, 0.01665773563658026`, 
      0.016712518912212034`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ll = % . Table[1, {Length[%]}]/Length[%]\)], "Input"],

Cell[BoxData[
    \(0.015799898583375264`\)], "Output"]
}, Open  ]],

Cell["\<\
Alternatively, we could have set up a nonlinear least-squares problem that \
solves for all the parameters in one fell swoop.  We can minimize the error \
directly using a \"canned\" minimization algorithm using the points that we \
had already determined as starting points for the algorithm.\
\>", "Text"],

Cell[BoxData[
    \(\(eqs = 
        Join[\(-t\)\ w\ m/\((1\  + \ \((t\ w)\)^2)\) - Li, 
          ll + m/\((1\  + \ \((t\ w)\)^2)\) - Lr];\)\)], "Input"],

Cell[BoxData[
    \(\(err = eqs . eqs;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[err, {m, M}, {t, tau}, {ll, Ll}]\)], "Input"],

Cell[BoxData[
    \({9.712655984715262`*^-6, {m \[Rule] 0.31642815879412195`, 
        t \[Rule] 0.16525773635459653`, 
        ll \[Rule] 0.016296292360173773`}}\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 727}},
WindowSize->{849, 649},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 96, 2, 53, "Subsubtitle"],
Cell[1875, 57, 261, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[2161, 66, 1110, 18, 201, "Input"],
Cell[3274, 86, 809, 12, 86, "Output"]
}, Open  ]],
Cell[4098, 101, 54, 1, 30, "Input"],
Cell[4155, 104, 134, 3, 33, "Text"],
Cell[4292, 109, 169, 3, 70, "Input"],
Cell[4464, 114, 88, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[4577, 120, 61, 1, 30, "Input"],
Cell[4641, 123, 625, 9, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5303, 137, 44, 1, 30, "Input"],
Cell[5350, 140, 320, 5, 48, "Output"]
}, Open  ]],
Cell[5685, 148, 43, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[5753, 152, 83, 1, 30, "Input"],
Cell[5839, 155, 78, 1, 29, "Output"]
}, Open  ]],
Cell[5932, 159, 62, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[6019, 163, 57, 1, 30, "Input"],
Cell[6079, 166, 54, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6170, 172, 53, 1, 30, "Input"],
Cell[6226, 175, 54, 1, 29, "Output"]
}, Open  ]],
Cell[6295, 179, 48, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[6368, 183, 86, 1, 30, "Input"],
Cell[6457, 186, 121, 2, 43, "Output"]
}, Open  ]],
Cell[6593, 191, 132, 3, 30, "Input"],
Cell[6728, 196, 127, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[6880, 203, 107, 2, 30, "Input"],
Cell[6990, 207, 27698, 598, 288, 4393, 306, "GraphicsData", "PostScript", \
"Graphics"],
Cell[34691, 807, 130, 3, 29, "Output"]
}, Open  ]],
Cell[34836, 813, 74, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[34935, 817, 64, 1, 30, "Input"],
Cell[35002, 820, 328, 5, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35367, 830, 73, 1, 30, "Input"],
Cell[35443, 833, 55, 1, 29, "Output"]
}, Open  ]],
Cell[35513, 837, 317, 5, 52, "Text"],
Cell[35833, 844, 154, 3, 30, "Input"],
Cell[35990, 849, 53, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[36068, 854, 77, 1, 30, "Input"],
Cell[36148, 857, 176, 3, 29, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

